\name{MIcombine}
\alias{MIcombine}
\alias{MIcombine.default}
\alias{MIcombine.imputationResultList}
\alias{print.MIresult}
\alias{summary.MIresult}
\alias{vcov.MIresult}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Multiple imputation inference}
\description{
Combines results of analyses on multiply imputed data sets. A generic
function with methods for \code{imputationResultList} objects and a
default method.  In addition to point estimates and variances,
\code{MIcombine} computes Rubin's degrees-of-freedom estimate and rate
of missing information.
}
\usage{
MIcombine(results, ...)
\method{MIcombine}{default}(results,variances,call=sys.call(),...)
\method{MIcombine}{imputationResultList}(results,call=NULL,...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{results}{A list of results from inference on separate imputed datasets}
  \item{variances}{If \code{results} is a list of parameter vectors,
    \code{variances} should be the corresponding variance-covariance
    matrices}
  \item{call}{A function call for labelling the results}
  \item{\dots}{Other arguments, not used}
}
\details{
   The
\code{results} argument in the default method may be either a list of
parameter vectors or a list of objects that have \code{coef} and
\code{vcov} methods.  In the former case a list of variance-covariance
matrices must be supplied as the second argument.
}
\value{
  An object of class \code{MIresult} with \code{summary} and
  \code{print} methods
}
\references{ ~put references to the literature/web site here ~ }
\seealso{ \code{\link{MIextract}}, \code{\link{with.imputationList}}}
\examples{
data(smi)
models<-with(smi, glm(drinkreg~wave*sex,family=binomial()))
summary(MIcombine(models))

betas<-MIextract(models,fun=coef)
vars<-MIextract(models, fun=vcov)
summary(MIcombine(betas,vars))
}
\keyword{htest}% at least one, from doc/KEYWORDS
\keyword{manip}% __ONLY ONE__ keyword per line

\eof
\name{MIextract}
\alias{MIextract}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Extract a parameter from a list of results }
\description{
 Used to extract parameter estimates and standard errors from
lists produced by \code{\link{with.imputationList}}.
}
\usage{
MIextract(results, expr, fun)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{results}{A list of objects}
  \item{expr}{an expression}
  \item{fun}{a function of one argument}
}
\value{
  A list
}
\details{
  If \code{expr} is supplied, it is evaluated in each element of
  \code{results}. Otherwise each element of \code{results} is passed as
  an argument to \code{fun}.
  }
\seealso{\code{\link{with.imputationList}}, \code{\link{MIcombine}}}
\examples{
data(smi)
models<-with(smi, glm(drinkreg~wave*sex,family=binomial()))

betas<-MIextract(models,fun=coef)
vars<-MIextract(models, fun=vcov)
summary(MIcombine(betas,vars))
}
\keyword{manip}% at least one, from doc/KEYWORDS


\eof
\name{imputationList}
\alias{imputationList}
\alias{print.imputationList}
\alias{rbind.imputationList}
\alias{cbind.imputationList}
\alias{dimnames.imputationList}
\alias{dim.imputationList}
\alias{update.imputationList}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Constructor for imputationList objects }
\description{
Create and update \code{imputationList} objects to be used as input to other
\code{MI} routines.
}
\usage{
imputationList(datasets)
\method{update}{imputationList}(object,...)
\method{rbind}{imputationList}(...)
\method{cbind}{imputationList}(...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{datasets}{a list of data frames corresponding to the multiple
    imputations}
  \item{object}{An object of class \code{imputationList}}
  \item{...}{Arguments \code{tag=expr} to \code{update}
    will create new variables \code{tag}  by evaluating \code{expr}
    in each imputed dataset}
}
\value{
An object of class \code{imputationList}
}
\examples{
data.dir<-system.file("dta",package="mitools")
files.men<-list.files(data.dir,pattern="m.\\.dta$",full=TRUE)
men<-imputationList(lapply(files.men, foreign::read.dta))
files.women<-list.files(data.dir,pattern="f.\\.dta$",full=TRUE)
women<-imputationList(lapply(files.women, foreign::read.dta))
men<-update(men, sex=1)
women<-update(women,sex=0)
all<-rbind(men,women)
all<-update(all, drinkreg=as.numeric(drkfre)>2)
all
}
\keyword{manip}% at aleast one, from doc/KEYWORDS


\eof
\name{smi}
\alias{smi}
\docType{data}
\title{Multiple imputations}
\description{
  An \code{imputationList} object containing five imputations of data
  from the Victorian Adolescent Health Cohort Study.
}
\usage{data(smi)}
\format{
  The underlying data are in a data frame with 1170 observations on the following 12 variables.
  \describe{
    \item{id}{a numeric vector}
    \item{wave}{a numeric vector}
    \item{mmetro}{a numeric vector}
    \item{parsmk}{a numeric vector}
    \item{drkfre}{a factor with levels \code{Non drinker} \code{not in last wk} \code{<3 days last wk} \code{>=3 days last wk}}
    \item{alcdos}{a factor with levels \code{Non drinker} \code{not in last wk} \code{av <5units/drink_day} \code{av =>5units/drink_day}}
    \item{alcdhi}{a numeric vector}
    \item{smk}{a factor with levels \code{non/ex-smoker} \code{<6 days} \code{6/7 days}}
    \item{cistot}{a numeric vector}
    \item{mdrkfre}{a numeric vector}
    \item{sex}{a numeric vector}
    \item{drinkreg}{a logical vector}
  }
}

\source{
  Carlin, JB, Li, N, Greenwood, P, Coffey, C. (2003) "Tools for
  analysing multiple imputed datasets" The Stata Journal 3; 3: 1-20.
}

\examples{
data(smi)
with(smi, table(sex, drkfre))
model1<-with(smi, glm(drinkreg~wave*sex, family=binomial()))
MIcombine(model1)
summary(MIcombine(model1))
}
\keyword{datasets}

\eof
\name{with.imputationList}
\alias{with.imputationList}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Evaluate an expression in multiple imputed datasets}
\description{
  Performs a computation of each of imputed datasets in \code{data}
  }
\usage{
\method{with}{imputationList}(data, expr, fun, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{An \code{imputationList} object }
  \item{expr}{An expression }
  \item{fun}{A function taking a data frame argument}
  \item{...}{Other arguments, passed to \code{fun} }
}
\value{
 Either a list or an \code{imputationResultList} object
}
\details{
 If \code{expr} is supplied, evaluate it in each dataset in \code{data};
if \code{fun} is supplied, it is evaluated on each dataset. If all the
results inherit from \code{"imputationResult"} the return value is an
\code{imputationResultList} object, otherwise it is an ordinary list.
}
\seealso{\code{\link{imputationList}} }
\examples{
data(smi)
models<-with(smi, glm(drinkreg~wave*sex,family=binomial()))
tables<-with(smi, table(drkfre,sex))
with(smi, fun=summary)
}
\keyword{manip}% at least one, from doc/KEYWORDS


\eof
